==> push.js-1.0.3.tgz: package/README.md <==
# [<img src="https://raw.githubusercontent.com/Nickersoft/push.js/master/logo.png" width="200">](http://pushjs.org)

[![Build Status](https://img.shields.io/travis/Nickersoft/push.js.svg)](https://travis-ci.org/Nickersoft/push.js) 
[![npm version](https://img.shields.io/npm/v/push.js.svg)](https://npmjs.com/package/push.js) 
[![npm](https://img.shields.io/npm/dm/push.js.svg)](https://npmjs.com/package/push.js) 
[![Coverage Status](https://img.shields.io/coveralls/Nickersoft/push.js.svg)](https://coveralls.io/github/Nickersoft/push.js?branch=master) 
[![Known Vulnerabilities](https://snyk.io/test/github/nickersoft/push.js/badge.svg)](https://snyk.io/test/github/nickersoft/push.js) 
![David Dependencies](https://img.shields.io/david/Nickersoft/push.js.svg)
[![Code Climate](https://img.shields.io/codeclimate/github/Nickersoft/push.js.svg)](https://codeclimate.com/github/Nickersoft/push.js)

*Now a proud user of*

[<img src="https://raw.githubusercontent.com/Nickersoft/push.js/master/browserstack.png" width="200px" />](https://browserstack.com)

### What is Push? ###

Push is the fastest way to get up and running with Javascript desktop notifications. A fairly new addition to the
official specification, the Notification API allows modern browsers such as Chrome, Safari, Firefox, and IE 9+ to push
notifications to a user's desktop. Push acts as a cross-browser solution to this API, falling back to use  older
implementations if the user's browser does not support the new API.

You can quickly install Push via [npm](http://npmjs.com):

```
npm install push.js --save
```

Or, if you want something a little more lightweight, you can give [Bower](http://bower.io) a try:

```
bower install push.js --save
```

### Full Documentation ###
Full documentation for Push can be found at the project's new homepage [https://pushjs.org](https://pushjs.org).
See you there!

### Development ###

If you feel like this library is your jam and you want to contribute (or you think I'm an idiot who missed something),
check out Push's neat [contributing guidelines](CONTRIBUTING.md) on how you can make your mark.

### Credits ###
Push is based off work the following work:

1. [HTML5-Desktop-Notifications](https://github.com/ttsvetko/HTML5-Desktop-Notifications) by [Tsvetan Tsvetkov](https://github.com/ttsvetko)
2. [notify.js](https://github.com/alexgibson/notify.js) by [Alex Gibson](https://github.com/alexgibson)

==> push.js-1.0.5.tgz: package/README.md <==
# [<img src="https://raw.githubusercontent.com/Nickersoft/push.js/master/logo.png" width="200">](http://pushjs.org)

[![Build Status](https://img.shields.io/travis/Nickersoft/push.js.svg)](https://travis-ci.org/Nickersoft/push.js) 
[![npm version](https://img.shields.io/npm/v/push.js.svg)](https://npmjs.com/package/push.js) 
[![npm](https://img.shields.io/npm/dm/push.js.svg)](https://npmjs.com/package/push.js) 
[![Coverage Status](https://img.shields.io/coveralls/Nickersoft/push.js.svg)](https://coveralls.io/github/Nickersoft/push.js?branch=master) 
[![Known Vulnerabilities](https://snyk.io/test/github/nickersoft/push.js/badge.svg)](https://snyk.io/test/github/nickersoft/push.js) 
![David Dev Dependencies](https://img.shields.io/david/dev/nickersoft/push.js.svg)
[![Code Climate](https://img.shields.io/codeclimate/github/Nickersoft/push.js.svg)](https://codeclimate.com/github/Nickersoft/push.js)

*Now a proud user of*

[<img src="https://raw.githubusercontent.com/Nickersoft/push.js/master/browserstack.png" width="200px" />](https://browserstack.com)

### What is Push? ###

Push is the fastest way to get up and running with Javascript desktop notifications. A fairly new addition to the
official specification, the Notification API allows modern browsers such as Chrome, Safari, Firefox, and IE 9+ to push
notifications to a user's desktop. Push acts as a cross-browser solution to this API, falling back to use  older
implementations if the user's browser does not support the new API.

You can quickly install Push via [npm](http://npmjs.com):

```
npm install push.js --save
```

Or, if you want something a little more lightweight, you can give [Bower](http://bower.io) a try:

```
bower install push.js --save
```

### Full Documentation ###
Full documentation for Push can be found at the project's new homepage [https://pushjs.org](https://pushjs.org).
See you there!

### Development ###

If you feel like this library is your jam and you want to contribute (or you think I'm an idiot who missed something),
check out Push's neat [contributing guidelines](CONTRIBUTING.md) on how you can make your mark.

### Credits ###
Push is based off work the following work:

1. [HTML5-Desktop-Notifications](https://github.com/ttsvetko/HTML5-Desktop-Notifications) by [Tsvetan Tsvetkov](https://github.com/ttsvetko)
2. [notify.js](https://github.com/alexgibson/notify.js) by [Alex Gibson](https://github.com/alexgibson)
